@@ -5,7 +5,7 @@ require pikzie module(http://pikzie.sourceforge.net/)
 """
 
 import sys
-sys.path.insert(0, '.')     ## test to development path
+sys.path.insert(0, './pyprof2html')     ## test to development path
 import pyprof2html as p2h
 
 # warning handling
@@ -26,6 +26,33 @@ class TestFileTypeCheck(pikzie.TestCase):
         self.assert_equal(False, p2h.check_hotshot("jotionfijeifje"))
 
 
+class TestConvertUnit(pikzie.TestCase):
+
+    def test_millisec1(self):
+        ret = p2h.convert_unit(0.01)
+        self.assert_equal(ret, "10.0 [ms]")
+
+    def test_millisec100(self):
+        ret = p2h.convert_unit(0.005)
+        self.assert_equal(ret, "5.0 [ms]")
+
+    def test_microsec1(self):
+        ret = p2h.convert_unit(0.0009)
+        self.assert_equal(ret, "900.0 [us]")
+
+    def test_microsec100(self):
+        ret = p2h.convert_unit(0.000009)
+        self.assert_equal(ret, "9.0 [us]")
+
+    def test_notconvert(self):
+        ret = p2h.convert_unit(1.008009)
+        self.assert_equal(ret, "1.008 [ s]")
+
+    def test_nanosec1(self):
+        ret = p2h.convert_unit(0.000000008)
+        self.assert_equal(ret, "8.0 [ns]")
+
+
 hotshotline_testdata_path = './test/hotshot.prof'
 hotshot_testdata_path = './test/hot.prof'
 cprof_testdata_path = './test/cprof.prof'
@@ -127,6 +154,18 @@ class ColorMappingTest(pikzie.TestCase):
 
 class FindFileCodec(pikzie.TestCase):
 
+    def test_emacs_style1_eucjp(self):
+        ret = p2h.detect_filecodec(["# -*- coding=euc-jp -*-"])
+        self.assert_equal(ret, 'euc-jp')
+
     def test_emacs_style1(self):
         ret = p2h.detect_filecodec(["# -*- coding=utf-8 -*-"])
         self.assert_equal(ret, 'utf-8')
+
+    def test_vim_style1(self):
+        ret = p2h.detect_filecodec(["# vim: fileencoding=utf-8"])
+        self.assert_equal(ret, 'utf-8')
+
+    def test_vim_style1_shiftjis(self):
+        ret = p2h.detect_filecodec(["# vim: fileencoding=shift_jis"])
+        self.assert_equal(ret, 'shift_jis')
